@@ -54,6 +54,7 @@
 #' @param Rp the decibel level that the cheby filter takes. see \code{\link[signal]{cheby1}}
 #' @param filterorder The order of the filter applied with respect to the cheby options. 
 #' @param hysteresis The hysteresis applied after zero crossing. (default 100mg)
+#' @param stft_win Window size in seconds for STFT computation. Increased window size mean better frequency resolution, but poorer time resolution. Defaults to 10 seconds.
 #' @details This function will apply the rules determined by the rpart GENEA 
 #' decision tree passed to argument trainingfit to the columns 
 #' of newdata to classify into classes 
@@ -101,6 +102,7 @@ classifyGENEA <- function(testfile,
                           Rp = 3,
                           plot.it = FALSE,
                           hysteresis = 0.1, 
+                          stft_win = 10, 
                           # Plots
                           plot.seg = FALSE, 
                           plot.seg.outputfile = "Changepoint",
@@ -168,7 +170,8 @@ classifyGENEA <- function(testfile,
                                   boundaries = boundaries, 
                                   Rp = Rp,
                                   plot.it = plot.it,
-                                  hysteresis = hysteresis, 
+                                  hysteresis = hysteresis,
+                                  stft_win = stft_win, 
                                   # Plots 
                                   plot.seg = plot.seg,
                                   plot.seg.outputfile = "Changepoint",
